
From: Janet Morgan <janetmor@us.ibm.com>

This patch provides more debug info when the system is OOM.  It displays
memory stats (basically sysrq-m info) from __alloc_pages() when page
allocation fails and during OOM kill.

Thanks to Dave Jones for coming up with the idea.

Signed-off-by: Janet Morgan <janetmor@us.ibm.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 mm/oom_kill.c   |    7 ++++---
 mm/page_alloc.c |    1 +
 2 files changed, 5 insertions(+), 3 deletions(-)

diff -puN mm/oom_kill.c~add-oom-debug mm/oom_kill.c
--- 25/mm/oom_kill.c~add-oom-debug	2005-06-06 00:13:55.000000000 -0700
+++ 25-akpm/mm/oom_kill.c	2005-06-06 00:13:55.000000000 -0700
@@ -258,6 +258,10 @@ void out_of_memory(unsigned int __nocast
 	struct mm_struct *mm = NULL;
 	task_t * p;
 
+	printk("oom-killer: gfp_mask=0x%x\n", gfp_mask);
+	/* print memory stats */
+	show_mem();
+
 	read_lock(&tasklist_lock);
 retry:
 	p = select_bad_process();
@@ -268,12 +272,9 @@ retry:
 	/* Found nothing?!?! Either we hang forever, or we panic. */
 	if (!p) {
 		read_unlock(&tasklist_lock);
-		show_free_areas();
 		panic("Out of memory and no killable processes...\n");
 	}
 
-	printk("oom-killer: gfp_mask=0x%x\n", gfp_mask);
-	show_free_areas();
 	mm = oom_kill_process(p);
 	if (!mm)
 		goto retry;
diff -puN mm/page_alloc.c~add-oom-debug mm/page_alloc.c
--- 25/mm/page_alloc.c~add-oom-debug	2005-06-06 00:13:55.000000000 -0700
+++ 25-akpm/mm/page_alloc.c	2005-06-06 00:13:55.000000000 -0700
@@ -935,6 +935,7 @@ nopage:
 			" order:%d, mode:0x%x\n",
 			p->comm, order, gfp_mask);
 		dump_stack();
+		show_mem();
 	}
 	return NULL;
 got_pg:
_
